interface DataWithTimestamp {
    time: number;
    data: any;
}
export declare class CacheUtils {
    /**
     * 如果缓存数据存在且可用，返回缓存数据，否则发送请求获取数据并存入缓存
     * @param caches 缓存Map
     * @param decode 取出缓存数据之后的解码方法
     * @param encode 保存缓存数据之前的编码方法
     * @param force 是否强制发送请求
     * @param usable 判断缓存数据是否可用的方法
     * @param requestMethod 请求方法
     * @param key 数据保存在数组中的key
     */
    static getCache: ({ caches, decode, encode, force, usable, requestMethod, key }: {
        caches: Map<any, any>;
        key: any;
        requestMethod: () => Promise<any>;
        force: boolean;
        usable?: ((cache: any) => boolean) | undefined;
        encode?: ((cache: any) => any) | undefined;
        decode?: ((cache: any) => any) | undefined;
    }) => Promise<any> | undefined;
    /**
     * 以时间为准判断缓存可用性
     * @param caches 缓存Map
     * @param decode 取出缓存数据之后的解码方法
     * @param force 是否强制发送请求
     * @param requestMethod 请求方法
     * @param seconds 过期时间
     * @param key 数据保存在数组中的key
     */
    static getCacheByTime: ({ caches, force, requestMethod, key, seconds }: {
        caches: Map<any, DataWithTimestamp>;
        key: any;
        requestMethod: () => Promise<any>;
        force: boolean;
        seconds: number;
    }) => Promise<any> | undefined;
}
export {};
