export interface Url {
    protocol: string;
    href: string;
    host: string;
    path: string;
    query: Query[];
}
export interface Query {
    key: string;
    value: string | number | Array<string | number>;
}
export declare class StringUtils {
    /**
     * 反转义
     * @param text 待转义字符串
     */
    static unEscape: (text: string) => string | null;
    /**
     * 解析一个URL
     * @param fullUrl url
     */
    static parseUrl: (fullUrl: string) => Url;
    /**
     * 解码unicode 各语言范围: https://baike.baidu.com/item/%E7%BB%9F%E4%B8%80%E7%A0%81/2985798
     * @param str 字符串
     */
    static decodeUnicode: (str: string) => string;
    /**
     * 编码unicode
     * @param str 字符串
     * @param radix 是否转换为16进制
     */
    static encodeUnicode: (str: string, radix?: number) => string;
    /**
     * 识别几种常用字符:中、日、韩、英、数字
     * @param str 字符
     */
    static language: (str: string) => string;
    /**
     * 向字符串的指定位置插入文本
     * @param sourceText 原字符串
     * @param suffix 后缀
     * @param prefix 前缀
     * @param start 开始位置
     * @param end 结束位置，不传表示只在start位置插入prefix+suffix，传递表示用prefix和suffix包裹之前在start和end中间的内容
     */
    static insertText({ sourceText, suffix, prefix, start, end }: InsertParam): {
        result: string;
        position: number[];
    };
}
export interface InsertParam {
    sourceText: string;
    prefix: string;
    suffix?: string;
    start: number;
    end?: number;
}
